@@ -1,26 +1,27 @@
 import sys
 from copy import deepcopy
-from datetime import timedelta
+from datetime import datetime, timedelta, timezone
 from os import environ
 
+import sentry_sdk
 from sentry_sdk.api import continue_trace
 from sentry_sdk.consts import OP
-from sentry_sdk.hub import Hub, _should_send_default_pii
+from sentry_sdk.scope import Scope, should_send_default_pii
 from sentry_sdk.tracing import TRANSACTION_SOURCE_COMPONENT
 from sentry_sdk.utils import (
     AnnotatedValue,
     capture_internal_exceptions,
+    ensure_integration_enabled,
     event_from_exception,
     logger,
     TimeoutThread,
+    reraise,
 )
 from sentry_sdk.integrations import Integration
 from sentry_sdk.integrations._wsgi_common import _filter_headers
-from sentry_sdk._compat import datetime_utcnow, reraise
 from sentry_sdk._types import TYPE_CHECKING
 
 if TYPE_CHECKING:
-    from datetime import datetime
     from typing import Any
     from typing import TypeVar
     from typing import Callable
@@ -37,20 +38,13 @@ MILLIS_TO_SECONDS = 1000.0
 
 def _wrap_init_error(init_error):
     # type: (F) -> F
+    @ensure_integration_enabled(AwsLambdaIntegration, init_error)
     def sentry_init_error(*args, **kwargs):
         # type: (*Any, **Any) -> Any
-
-        hub = Hub.current
-        integration = hub.get_integration(AwsLambdaIntegration)
-        if integration is None:
-            return init_error(*args, **kwargs)
-
-        # If an integration is there, a client has to be there.
-        client = hub.client  # type: Any
+        client = sentry_sdk.get_client()
 
         with capture_internal_exceptions():
-            with hub.configure_scope() as scope:
-                scope.clear_breadcrumbs()
+            Scope.get_isolation_scope().clear_breadcrumbs()
 
             exc_info = sys.exc_info()
             if exc_info and all(exc_info):
@@ -59,7 +53,7 @@ def _wrap_init_error(init_error):
                     client_options=client.options,
                     mechanism={"type": "aws_lambda", "handled": False},
                 )
-                hub.capture_event(sentry_event, hint=hint)
+                sentry_sdk.capture_event(sentry_event, hint=hint)
 
         return init_error(*args, **kwargs)
 
@@ -68,6 +62,7 @@ def _wrap_init_error(init_error):
 
 def _wrap_handler(handler):
     # type: (F) -> F
+    @ensure_integration_enabled(AwsLambdaIntegration, handler)
     def sentry_handler(aws_event, aws_context, *args, **kwargs):
         # type: (Any, Any, *Any, **Any) -> Any
 
@@ -81,7 +76,7 @@ def _wrap_handler(handler):
         # will be the same for all events in the list, since they're all hitting
         # the lambda in the same request.)
 
-        if isinstance(aws_event, list):
+        if isinstance(aws_event, list) and len(aws_event) >= 1:
             request_data = aws_event[0]
             batch_size = len(aws_event)
         else:
@@ -94,16 +89,12 @@ def _wrap_handler(handler):
             # this is empty
             request_data = {}
 
-        hub = Hub.current
-        integration = hub.get_integration(AwsLambdaIntegration)
-        if integration is None:
-            return handler(aws_event, aws_context, *args, **kwargs)
+        client = sentry_sdk.get_client()
+        integration = client.get_integration(AwsLambdaIntegration)
 
-        # If an integration is there, a client has to be there.
-        client = hub.client  # type: Any
         configured_time = aws_context.get_remaining_time_in_millis()
 
-        with hub.push_scope() as scope:
+        with sentry_sdk.isolation_scope() as scope:
             timeout_thread = None
             with capture_internal_exceptions():
                 scope.clear_breadcrumbs()
@@ -137,9 +128,10 @@ def _wrap_handler(handler):
                     # Starting the thread to raise timeout warning exception
                     timeout_thread.start()
 
-            headers = request_data.get("headers")
-            # AWS Service may set an explicit `{headers: None}`, we can't rely on `.get()`'s default.
-            if headers is None:
+            headers = request_data.get("headers", {})
+            # Some AWS Services (ie. EventBridge) set headers as a list
+            # or None, so we must ensure it is a dict
+            if not isinstance(headers, dict):
                 headers = {}
 
             transaction = continue_trace(
@@ -147,8 +139,9 @@ def _wrap_handler(handler):
                 op=OP.FUNCTION_AWS,
                 name=aws_context.function_name,
                 source=TRANSACTION_SOURCE_COMPONENT,
+                origin=AwsLambdaIntegration.origin,
             )
-            with hub.start_transaction(
+            with sentry_sdk.start_transaction(
                 transaction,
                 custom_sampling_context={
                     "aws_event": aws_event,
@@ -164,7 +157,7 @@ def _wrap_handler(handler):
                         client_options=client.options,
                         mechanism={"type": "aws_lambda", "handled": False},
                     )
-                    hub.capture_event(sentry_event, hint=hint)
+                    sentry_sdk.capture_event(sentry_event, hint=hint)
                     reraise(*exc_info)
                 finally:
                     if timeout_thread:
@@ -176,16 +169,17 @@ def _wrap_handler(handler):
 def _drain_queue():
     # type: () -> None
     with capture_internal_exceptions():
-        hub = Hub.current
-        integration = hub.get_integration(AwsLambdaIntegration)
+        client = sentry_sdk.get_client()
+        integration = client.get_integration(AwsLambdaIntegration)
         if integration is not None:
             # Flush out the event queue before AWS kills the
             # process.
-            hub.flush()
+            client.flush()
 
 
 class AwsLambdaIntegration(Integration):
     identifier = "aws_lambda"
+    origin = f"auto.function.{identifier}"
 
     def __init__(self, timeout_warning=False):
         # type: (bool) -> None
@@ -210,7 +204,7 @@ class AwsLambdaIntegration(Integration):
             )
             return
 
-        pre_37 = hasattr(lambda_bootstrap, "handle_http_request")  # Python 3.6 or 2.7
+        pre_37 = hasattr(lambda_bootstrap, "handle_http_request")  # Python 3.6
 
         if pre_37:
             old_handle_event_request = lambda_bootstrap.handle_event_request
@@ -286,8 +280,6 @@ class AwsLambdaIntegration(Integration):
 def get_lambda_bootstrap():
     # type: () -> Optional[Any]
 
-    # Python 2.7: Everything is in `__main__`.
-    #
     # Python 3.7: If the bootstrap module is *already imported*, it is the
     # one we actually want to use (no idea what's in __main__)
     #
@@ -324,7 +316,7 @@ def get_lambda_bootstrap():
 
 def _make_request_event_processor(aws_event, aws_context, configured_timeout):
     # type: (Any, Any, Any) -> EventProcessor
-    start_time = datetime_utcnow()
+    start_time = datetime.now(timezone.utc)
 
     def event_processor(sentry_event, hint, start_time=start_time):
         # type: (Event, Hint, datetime) -> Optional[Event]
@@ -360,7 +352,7 @@ def _make_request_event_processor(aws_event, aws_context, configured_timeout):
         if "headers" in aws_event:
             request["headers"] = _filter_headers(aws_event["headers"])
 
-        if _should_send_default_pii():
+        if should_send_default_pii():
             user_info = sentry_event.setdefault("user", {})
 
             identity = aws_event.get("identity")
@@ -429,7 +421,9 @@ def _get_cloudwatch_logs_url(aws_context, start_time):
         log_group=aws_context.log_group_name,
         log_stream=aws_context.log_stream_name,
         start_time=(start_time - timedelta(seconds=1)).strftime(formatstring),
-        end_time=(datetime_utcnow() + timedelta(seconds=2)).strftime(formatstring),
+        end_time=(datetime.now(timezone.utc) + timedelta(seconds=2)).strftime(
+            formatstring
+        ),
     )
 
     return url
