@@ -33,6 +33,7 @@ import sys
 import threading
 import time
 import uuid
+import warnings
 from abc import ABC, abstractmethod
 from collections import deque
 
@@ -213,7 +214,6 @@ class Profile:
     ):
         # type: (...) -> None
         self.scheduler = _scheduler if scheduler is None else scheduler
-        self.hub = hub
 
         self.event_id = uuid.uuid4().hex  # type: str
 
@@ -240,6 +240,16 @@ class Profile:
 
         self.unique_samples = 0
 
+        # Backwards compatibility with the old hub property
+        self._hub = None  # type: Optional[sentry_sdk.Hub]
+        if hub is not None:
+            self._hub = hub
+            warnings.warn(
+                "The `hub` parameter is deprecated. Please do not use it.",
+                DeprecationWarning,
+                stacklevel=2,
+            )
+
     def update_active_thread_id(self):
         # type: () -> None
         self.active_thread_id = get_current_thread_meta()[0]
@@ -506,6 +516,26 @@ class Profile:
 
         return True
 
+    @property
+    def hub(self):
+        # type: () -> Optional[sentry_sdk.Hub]
+        warnings.warn(
+            "The `hub` attribute is deprecated. Please do not access it.",
+            DeprecationWarning,
+            stacklevel=2,
+        )
+        return self._hub
+
+    @hub.setter
+    def hub(self, value):
+        # type: (Optional[sentry_sdk.Hub]) -> None
+        warnings.warn(
+            "The `hub` attribute is deprecated. Please do not set it.",
+            DeprecationWarning,
+            stacklevel=2,
+        )
+        self._hub = value
+
 
 class Scheduler(ABC):
     mode = "unknown"  # type: ProfilerMode
